# regular build/usage images
ifeq (distro,$(IMAGE_CLASS))

mixin/ximper-gnome3: use/x11/gnome3/minimal use/fonts/ttf/redhat +nm-gtk
	@$(call add,THE_PACKAGES,xcalib templates)
	@$(call add,THE_PACKAGES,sudo)
	@$(call add,CONTROL,sudowheel:enabled)
	@$(call add,THE_PACKAGES,chrome-gnome-shell)
	@$(call add,THE_PACKAGES,qt5-wayland gnome-terminal-nautilus sushi gradience Kvantum)
	@$(call add,THE_PACKAGES,appinstall gnome-software)
	@$(call add,THE_PACKAGES,gnome-shell-extension-appindicator gnome-shell-extension-dash-to-dock gnome-shell-extension-gsconnect\
	branding-etersoft-ximper-gnome-settings)

ifeq (sisyphus,$(BRANCH))
	@$(call add,THE_PACKAGES,gnome-packagekit)
endif

# common ground (really lowlevel)
distro/.ximper-bare: distro/.base use/kernel/net use/docs/license \
	use/stage2/ata use/stage2/fs use/stage2/hid use/stage2/md \
	use/stage2/mmc use/stage2/net use/stage2/net-nfs use/stage2/cifs \
	use/stage2/rtc use/stage2/sbc use/stage2/scsi use/stage2/usb \
	use/stage2/drm use/tty
	@$(call try,SAVE_PROFILE,yes)
	@$(call add,STAGE1_PACKAGES,firmware-linux)
	@$(call add,STAGE1_KMODULES,drm)
ifeq (sisyphus,$(BRANCH))
ifeq (,$(filter-out i586 x86_64,$(ARCH)))
	@$(call set,BOOTLOADER,grubpcboot)
endif
endif

# base target (for most images)
distro/.ximper-base: distro/.ximper-bare use/vmguest use/memtest use/efi/dtb +efi; @:


# graphical target (not enforcing xorg drivers or blobs)
distro/.ximper-x11: distro/.ximper-base mixin/regular-x11 \
	use/x11/wacom use/x11/amdgpu +wireless \
	use/live/x11 use/live/repo \
	use/live/suspend use/browser/firefox \
	use/syslinux/ui/gfxboot use/grub/ui/gfxboot
	@$(call add,THE_BRANDING,bootloader)
	@$(call add,THE_LISTS,$(call tags,(base || desktop) && regular))
	@$(call add,LIVE_LISTS,$(call tags,base rescue))
	@$(call add,LIVE_PACKAGES,gpm)
	@$(call add,DEFAULT_SERVICES_DISABLE,gpm powertop)

distro/.ximper-wm: distro/.ximper-x11 \
	mixin/regular-desktop +vmguest \
	use/live/rw +live-installer
	@$(call set,INSTALLER,alt-workstation)
	@$(call set,GRUB_DEFAULT,live)
	@$(call set,SYSLINUX_DEFAULT,live)

# DE base target
# TODO: use/plymouth/live when luks+plymouth is done, see also #28255
distro/.ximper-desktop: distro/.ximper-wm use/branding/full \
	use/firmware/laptop +systemd +systemd-optimal
	@$(call add,THE_PACKAGES,bluez)
	@$(call add,THE_PACKAGES,btrfs-progs)
	@$(call add,DEFAULT_SERVICES_ENABLE,bluetoothd)

distro/.ximper-install: distro/.ximper-base +installer \
	use/branding use/bootloader/grub use/luks use/stage2/kms \
	use/install2/fs use/install2/vnc use/install2/repo
	@$(call add,INSTALL2_PACKAGES,fdisk)
ifeq (,$(filter-out i586 x86_64,$(ARCH)))
	@$(call add,INSTALL2_PACKAGES,xorg-conf-synaptics)
endif
	@$(call add,THE_LISTS,$(call tags,base regular))
	@$(call add,INSTALL2_BRANDING,alterator notes)
	@$(call add,INSTALL2_PACKAGES,btrfs-progs)
	@$(call add,THE_BRANDING,alterator)


distro/.ximper-install-x11: distro/.ximper-install +vmguest +wireless \
	use/install2/suspend mixin/regular-desktop mixin/regular-x11 \
	use/branding/complete use/branding/slideshow/once use/rescue/base
	@$(call set,INSTALLER,alt-workstation)

# assumes somewhat more experienced user
distro/.ximper-install-x11-full: distro/.ximper-install-x11 \
	use/fonts/otf/adobe use/fonts/otf/mozilla use/fonts/chinese \
	mixin/desktop-installer use/install2/fs use/efi/shell use/rescue/base
	@$(call add,RESCUE_LISTS,$(call tags,rescue misc))
	@$(call add,MAIN_PACKAGES,anacron man-whatis usb-modeswitch)

distro/.ximper-install-x11-systemd: distro/.ximper-install-x11 \
	use/x11/lightdm/gtk +systemd +systemd-optimal
	@$(call add,THE_PACKAGES,bluez)
	@$(call add,DEFAULT_SERVICES_ENABLE,bluetoothd)

distro/ximper-install: distro/.ximper-install-x11-systemd mixin/ximper-gnome3 \
	use/kernel/latest +plymouth; @:
	@$(call add,MAIN_GROUPS,etersoft/00_office etersoft/libreoffice-still etersoft/libreoffice-latest \
	slinux/flatpak slinux/graphics-base slinux/graphics slinux/graphics-full-inkscape slinux/graphics-full-shotwell\
	 slinux/multimedia-full-audacity etersoft/multimedia-base\
	 etersoft/multimedia-mpv slinux/multimedia slinux/multimedia-full-shotcut\
	 etersoft/virt-machines etersoft/virt-manager etersoft/gnome-boxes etersoft/virtualbox\
	 etersoft/01_games etersoft/games-portproton etersoft/games-lutris etersoft/games-mangohud etersoft/games-32bit-libs etersoft/games-vkbasalt\
	 etersoft/02_peripheral etersoft/peripherals-openrgb)

distro/ximper: distro/.ximper-desktop mixin/regular-gnome3 \
	use/kernel/latest +plymouth
	@$(call add,LIVE_PACKAGES,livecd-gnome3-setup-done)
	@$(call add,LIVE_PACKAGES,gnome-flashback screenpen)

endif